#ifndef YYSTYPE
#define YYSTYPE int
#endif
#define	T_NUMBER	258
#define	T_SYMBOL	259
#define	T_LITERAL	260
#define	T_DIGITS	261
#define	T_QUOTE	262
#define	T_QUOTE2	263
#define	T_QUOTE3	264
#define	T_EQUAL	265
#define	T_NOTEQ	266
#define	T_LESSEQ	267
#define	T_GREATEREQ	268
#define	T_MATRIX_BEGIN	269
#define	T_MATRIX_END	270
#define	T_QUIT	271
#define	T_WARRANTY	272
#define	T_PRINT	273
#define	T_READ	274
#define	T_WRITE	275
#define	T_TIME	276
#define	T_XYZZY	277
#define	T_INVENTORY	278
#define	T_LOOK	279
#define	T_SCORE	280
#define	NEG	281


extern YYSTYPE yylval;
